@@ -72,15 +72,28 @@ public:
   virtual void load_from_document(); //View override
 
   typedef std::vector< sharedptr<Field> > type_vecFields;
+  typedef std::vector< sharedptr<const Field> > type_vecConstFields;
 
   static type_vecFields get_fields_for_table_from_database(const Glib::ustring& table_name, bool including_system_fields = false);
   static bool get_field_exists_in_database(const Glib::ustring& table_name, const Glib::ustring& field_name);
 
 
-  static Glib::RefPtr<Gnome::Gda::DataModel> query_execute(const Glib::ustring& strQuery, Gtk::Window* parent_window = 0);
+  /** Execute a SQL Select command, returning the result.
+   * This method handles any Gda exceptions caused by executing the command.
+   */
+  static Glib::RefPtr<Gnome::Gda::DataModel> query_execute_select(const Glib::ustring& strQuery, 
+                                                                  const Glib::RefPtr<Gnome::Gda::Set>& params = Glib::RefPtr<Gnome::Gda::Set>(0));
+
+
+  /** Execute a SQL non-select command, returning true if it succeeded.
+   * This method handles any Gda exceptions caused by executing the command.
+   */
+  static bool query_execute(const Glib::ustring& strQuery,
+                            const Glib::RefPtr<Gnome::Gda::Set>& params = Glib::RefPtr<Gnome::Gda::Set>(0));
+
   static int count_rows_returned_by(const Glib::ustring& sql_query);
 
-
+#ifndef GLOM_ENABLE_CLIENT_ONLY
   bool add_standard_groups();
   bool add_standard_tables() const;
 
@@ -90,6 +103,17 @@ public:
   /// Also saves the table information in the document:
   bool create_table_with_default_fields(const Glib::ustring& table_name);
 
+  // TODO: Should these functions update the document, so callers don't need
+  // to do it?
+  bool add_column(const Glib::ustring& table_name, const sharedptr<const Field>& field, Gtk::Window* parent_window) const;
+
+  bool drop_column(const Glib::ustring& table_name, const Glib::ustring& field_name, Gtk::Window* parent_window) const;
+
+  sharedptr<Field> change_column(const Glib::ustring& table_name, const sharedptr<const Field>& field_old, const sharedptr<const Field>& field, Gtk::Window* parent_window) const;
+
+  bool change_columns(const Glib::ustring& table_name, const type_vecConstFields& old_fields, type_vecFields& fields, Gtk::Window* parent_window) const;
+#endif //GLOM_ENABLE_CLIENT_ONLY
+
   bool insert_example_data(const Glib::ustring& table_name) const;
 
   typedef std::vector< sharedptr<LayoutItem_Field> > type_vecLayoutFields;
@@ -116,7 +140,20 @@ protected:
   bool get_table_exists_in_database(const Glib::ustring& table_name) const;
   bool get_relationship_exists(const Glib::ustring& table_name, const Glib::ustring& relationship_name);
 
+  /** Get all the fields for a table, including any from the datasbase that are not yet known in the document.
+   *
+   * @param table_name The name of the table whose fields should be listed.
+   * @param including_system_fields Whether extra non-user-visible fields should be included in the list.
+   * @result A list of fields.
+   */
   type_vecFields get_fields_for_table(const Glib::ustring& table_name, bool including_system_fields = false) const;
+
+  /** Get a single field definition for a table, even if the field is in the datasbase but not yet known in the document.
+   *
+   * @param table_name The name of the table whose fields should be listed.
+   * @param field_name The name of the field for which to get the definition.
+   * @result The field definition.
+   */
   sharedptr<Field> get_fields_for_table_one_field(const Glib::ustring& table_name, const Glib::ustring& field_name) const;
 
   sharedptr<Field> get_field_primary_key_for_table(const Glib::ustring& table_name) const;
@@ -267,9 +304,13 @@ protected:
   bool set_field_value_in_database(const LayoutFieldInRecord& field_in_record, const Gnome::Gda::Value& field_value, bool use_current_calculations = false, Gtk::Window* parent_window = 0);
   bool set_field_value_in_database(const LayoutFieldInRecord& field_in_record, const Gtk::TreeModel::iterator& row, const Gnome::Gda::Value& field_value, bool use_current_calculations = false, Gtk::Window* parent_window = 0);
 
-  //Get a single field value from the database.
+  ///Get a single field value from the database.
   Gnome::Gda::Value get_field_value_in_database(const LayoutFieldInRecord& field_in_record, Gtk::Window* parent_window);
 
+  ///Get a single field value from the database.
+  Gnome::Gda::Value get_field_value_in_database(const sharedptr<Field>& field, const FoundSet& found_set, Gtk::Window* parent_window);
+
+
 
   SystemPrefs get_database_preferences() const;
   void set_database_preferences(const SystemPrefs& prefs);
@@ -312,6 +353,24 @@ protected:
 
   bool get_primary_key_is_in_foundset(const FoundSet& found_set, const Gnome::Gda::Value& primary_key_value);
 
+
+  /** A utility function to set the where_clause, even for doubly-related records.
+   *
+   * @param found_set The FoundSet to change.
+   * @param portal The related records portal whose records should be selected by the SQL query.
+   * @param foreign_key_value The value of the from field in the parent table.
+   */
+  void set_found_set_where_clause_for_portal(FoundSet& found_set, const sharedptr<LayoutItem_Portal>& portal, const Gnome::Gda::Value& foreign_key_value);
+
+  /** Update GDA's information about the table structure, such as the 
+   * field list and their types.
+   * Call this whenever changing the table structure, for instance with an ALTER query.
+   * This may take a few seconds to return.
+   */
+  void update_gda_metastore_for_table(const Glib::ustring& table_name) const;
+  
+  static Glib::RefPtr<Gnome::Gda::Connection> get_connection();
+
   static bool get_field_primary_key_index_for_fields(const type_vecFields& fields, guint& field_column);
   static bool get_field_primary_key_index_for_fields(const type_vecLayoutFields& fields, guint& field_column);
 
