@@ -21,7 +21,7 @@
 #ifndef DOCUMENT_GLOM_H
 #define DOCUMENT_GLOM_H
 
-#include "config.h" // For GLOM_ENABLE_CLIENT_ONLY
+#include "config.h" // For GLOM_ENABLE_CLIENT_ONLY, GLOM_ENABLE_SQLITE
 
 #include <bakery/Document/Document_XML.h>
 #include <bakery/View/View_Composite.h>
@@ -52,24 +52,22 @@ template<class T_Element>
 class predicate_Layout
 {
 public:
-  predicate_Layout(const Glib::ustring& parent_table, const Glib::ustring& layout_name)
+  predicate_Layout(const Glib::ustring& parent_table, const Glib::ustring& layout_name, const Glib::ustring& layout_platform)
   : m_parent_table(parent_table),
-    m_layout_name(layout_name)
-  {
-  }
-
-  virtual ~predicate_Layout()
+    m_layout_name(layout_name),
+    m_layout_platform(layout_platform)
   {
   }
 
   bool operator() (const T_Element& element)
   {
     return (element.m_parent_table == m_parent_table) &&
-           (element.m_layout_name == m_layout_name);
+           (element.m_layout_name == m_layout_name) &&
+           (element.m_layout_platform == m_layout_platform);
   }
 
 protected:
-  Glib::ustring m_parent_table, m_layout_name;
+  Glib::ustring m_parent_table, m_layout_name, m_layout_platform;
 };
 
 class Document_Glom : public Bakery::Document_XML
@@ -112,12 +110,18 @@ public:
 
   static guint get_latest_known_document_format_version();
 
-#ifndef GLOM_ENABLE_CLIENT_ONLY
-  /** When this is set, the postgres database is hosted by the local client,
-   *  instead of connecting to an external database server.
+  enum HostingMode
+  {
+    POSTGRES_CENTRAL_HOSTED, /*!< The database is hosted on an external postgresql server. */
+    POSTGRES_SELF_HOSTED, /*!< A new postgres database process is spawned that hosts the data. */
+#ifdef GLOM_ENABLE_SQLITE
+    SQLITE_HOSTED /*!< A sqlite database file is used. */
+#endif // GLOM_ENABLE_SQLITE
+  };
+
+  /** Set the hosting mode of the database.
    */
-  void set_connection_is_self_hosted(bool self_hosted = true);
-#endif // !GLOM_ENABLE_CLIENT_ONLY
+  void set_hosting_mode(HostingMode mode);
 
   void set_connection_server(const Glib::ustring& strVal);
   void set_connection_user(const Glib::ustring& strVal);
@@ -125,18 +129,17 @@ public:
   void set_connection_port(int port_number);
   void set_connection_try_other_ports(bool val);
 
-#ifndef GLOM_ENABLE_CLIENT_ONLY
-  /** When this returns true, the postgres database should be hosted by the local client,
-   *  instead of connecting to an external database server.
+  /** This returns how the hosting mode of the database.
    */
-  bool get_connection_is_self_hosted() const;
+  HostingMode get_hosting_mode() const;
 
   /** If the database should be hosted, this provides the 
     * path to the directory that contains all the files needed to do that.
     * This is usually a specifically-named directory at the same level as the .glom file. 
+    * If the database is a sqlite database, this specifies the directory in
+    * which the database file is in.
     */   
   std::string get_connection_self_hosted_directory_uri() const;
-#endif // !GLOM_ENABLE_CLIENT_ONLY
 
   Glib::ustring get_connection_server() const;
   Glib::ustring get_connection_user() const;
@@ -172,8 +175,7 @@ public:
   /** Returns whether the field is the from-field in a to-one relationship.
    * @see get_relationship_is_to_one(). Ignores hidden tables.
    */
-  sharedptr<Relationship> get_field_used_in_relationship_to_one(const Glib::ustring& table_name, const Glib::ustring& field_name) const;
-
+  sharedptr<Relationship> get_field_used_in_relationship_to_one(const Glib::ustring& table_name, const sharedptr<const LayoutItem_Field>& layout_field) const;
 
   typedef std::vector< sharedptr<Field> > type_vecFields;
   type_vecFields get_table_fields(const Glib::ustring& table_name) const;
@@ -192,31 +194,35 @@ public:
   /** Get the layout groups for a layout.
    * @param layout_name The name of the layout, such as list or details.
    * @param parent_table_name The name of the table for which this layout should appear.
+   * @param layout_platform The platform for which this layout should be used. Possible values are an empty string (meaning normal platforms) or "maemo" meaning "normal". 
    * @result A list of layout groups at the top-level of the requested layout.
    */
-  type_list_layout_groups get_data_layout_groups(const Glib::ustring& layout_name, const Glib::ustring& parent_table_name) const;
+  type_list_layout_groups get_data_layout_groups(const Glib::ustring& layout_name, const Glib::ustring& parent_table_name, const Glib::ustring& layout_platform) const;
 
   /** Discover whether there are any fields in the layout.
    * @param layout_name The name of the layout, such as list or details.
    * @param parent_table_name The name of the table for which this layout should appear.
+   * @param layout_platform The platform for which this layout should be used. Possible values are an empty string (meaning normal platforms) or "maemo" meaning "normal". 
    * @result true if there is at least one field in the layout group or its sub groups.
    */
-  bool get_data_layout_groups_have_any_fields(const Glib::ustring& layout_name, const Glib::ustring& parent_table_name) const;
+  bool get_data_layout_groups_have_any_fields(const Glib::ustring& layout_name, const Glib::ustring& parent_table_name, const Glib::ustring& layout_platform) const;
 
   /** Set the layout groups for a layout.
    * @param layout_name The name of the layout, such as list or details.
    * @param parent_table_name The name of the table for which this layout should appear.
+   * @param layout_platform The platform for which this layout should be used. Possible values are an empty string (meaning normal platforms) or "maemo" meaning "normal". 
    * @param groups A list of layout groups at the top-level of the requested layout.
    */
-  void set_data_layout_groups(const Glib::ustring& layout_name, const Glib::ustring& parent_table_name, const type_list_layout_groups& groups);
+  void set_data_layout_groups(const Glib::ustring& layout_name, const Glib::ustring& parent_table_name, const Glib::ustring& layout_platform, const type_list_layout_groups& groups);
 
   /**
    * @para The layout_name, such as "details", "list".
    * @para parent_table_name The name of the table on whose layout the layout appears.
+   * @param layout_platform The platform for which this layout should be used. Possible values are an empty string (meaning normal platforms) or "maemo" meaning "normal". 
    */
-  type_list_layout_groups get_data_layout_groups_plus_new_fields(const Glib::ustring& layout_name, const Glib::ustring& parent_table_name) const;
+  type_list_layout_groups get_data_layout_groups_plus_new_fields(const Glib::ustring& layout_name, const Glib::ustring& parent_table_name, const Glib::ustring& layout_platform) const;
 
-  type_list_layout_groups get_data_layout_groups_default(const Glib::ustring& layout_name, const Glib::ustring& parent_table_name) const;
+  type_list_layout_groups get_data_layout_groups_default(const Glib::ustring& layout_name, const Glib::ustring& parent_table_name, const Glib::ustring& layout_platform) const;
 
   typedef std::list< sharedptr<TranslatableItem> > type_list_translatables;
   type_list_translatables get_translatable_layout_items(const Glib::ustring& table_name);
@@ -257,14 +263,17 @@ public:
   Glib::ustring get_table_title(const Glib::ustring& table_name) const;
   void set_table_title(const Glib::ustring& table_name, const Glib::ustring& value);
 
+  typedef std::vector< Gnome::Gda::Value > type_row_data;
+  typedef std::vector< type_row_data > type_example_rows;
+
   /** Save example data into the document, for use when creating the example database on the server.
    * Don't use this for large amounts of data.
    * @param table_name The table that should contain this example data.
    * @param rows Each row is separated by a newline. Each line has comma-separated field values, in SQL format.
    */
-  void set_table_example_data(const Glib::ustring& table_name, const Glib::ustring& rows);
+  void set_table_example_data(const Glib::ustring& table_name, const type_example_rows& rows);
 
-  Glib::ustring get_table_example_data(const Glib::ustring& table_name) const;
+  type_example_rows get_table_example_data(const Glib::ustring& table_name) const;
 
   virtual Glib::ustring get_name() const; //override.
 
@@ -376,6 +385,18 @@ public:
 
   void emit_userlevel_changed();
 
+  static Glib::ustring get_default_layout_platform();
+
+  /** This is transitory information, not saved to disk.
+   */
+  Glib::ustring get_active_layout_platform() const;
+
+  /** This is transitory information, not saved to disk.
+   */
+  void set_active_layout_platform(const Glib::ustring& layout_platform);
+
+
+
   void set_parent_window(Gtk::Window* window);
 
   Glib::ustring build_and_get_contents() const;
@@ -438,8 +459,10 @@ protected:
   static void set_node_attribute_value_as_bool(xmlpp::Element* node, const Glib::ustring& strAttributeName, bool value = true, bool value_default = false);
   static void set_node_attribute_value_as_float( xmlpp::Element* node, const Glib::ustring& strAttributeName, float value );
   static void set_node_attribute_value_as_value(xmlpp::Element* node, const Glib::ustring& strAttributeName, const Gnome::Gda::Value& value, Field::glom_field_type field_type);
+  static void set_node_text_child_as_value(xmlpp::Element* node, const Gnome::Gda::Value& value, Field::glom_field_type field_type);
 #endif // !GLOM_ENABLE_CLIENT_ONLY
   static Gnome::Gda::Value get_node_attribute_value_as_value(const xmlpp::Element* node, const Glib::ustring& strAttributeName, Field::glom_field_type field_type);
+  static Gnome::Gda::Value get_node_text_child_as_value(const xmlpp::Element* node, Field::glom_field_type field_type);
 
   Glib::ustring get_child_text_node(const xmlpp::Element* node, const Glib::ustring& child_node_name) const;
   void set_child_text_node(xmlpp::Element* node, const Glib::ustring& child_node_name, const Glib::ustring& text);
@@ -447,9 +470,7 @@ protected:
   AppState m_app_state;
   type_signal_userlevel_changed m_signal_userlevel_changed;
 
-#ifndef GLOM_ENABLE_CLIENT_ONLY
-  bool m_connection_is_self_hosted;
-#endif // !GLOM_ENABLE_CLIENT_ONLY
+  HostingMode m_hosting_mode;
 
   Glib::ustring m_connection_server, m_connection_user, m_connection_database;
   int m_connection_port; //0 means any port. Ignored when self-hosting (which may use a different port each time).
@@ -459,6 +480,7 @@ protected:
   {
   public:
     Glib::ustring m_layout_name;
+    Glib::ustring m_layout_platform; //Empty string (meaning normal platforms), or "maemo", or something else.
     Glib::ustring m_parent_table;
 
     type_list_layout_groups m_layout_groups;
@@ -476,7 +498,8 @@ protected:
 
     //TODO: Avoid the use of this:
     DocumentTableInfo(const DocumentTableInfo& src)
-      : m_fields(src.m_fields),
+      : m_info(src.m_info),
+        m_fields(src.m_fields),
         m_relationships(src.m_relationships),
         m_layouts(src.m_layouts),
         m_reports(src.m_reports),
@@ -493,6 +516,7 @@ protected:
     //TODO: Avoid the use of this:
     DocumentTableInfo& operator=(const DocumentTableInfo& src)
     {
+      m_info = src.m_info;
       m_fields = src.m_fields;
       m_relationships = src.m_relationships;
       m_layouts = src.m_layouts;
@@ -522,7 +546,8 @@ protected:
     typedef std::map< Glib::ustring, sharedptr<PrintLayout> > type_print_layouts; //map of print layout names to print layouts
     type_print_layouts m_print_layouts;
 
-    Glib::ustring m_example_rows;
+    //Example data, used when creating a database from an example.
+    type_example_rows m_example_rows;
 
     //Per-session, not saved in document:
     typedef std::map<Glib::ustring, Gnome::Gda::Value> type_map_layout_primarykeys;
@@ -559,6 +584,8 @@ protected:
 
   bool m_opened_from_browse;
 
+  Glib::ustring m_active_layout_platform; //empty (means normal), or "maemo".
+
   Gtk::Window* m_parent_window; //Needed by BusyCursor.
 };
 
