@@ -147,7 +147,6 @@ void Box_Data_Details::set_primary_key_value(const Gtk::TreeModel::iterator& /*
 {
   m_primary_key_value = value;
   set_found_set_from_primary_key_value();
-  //std::cout << "Box_Data_Details::set_primary_key_value(): m_primary_key_value=" << m_field_primary_key->sql(m_primary_key_value) << std::endl;
 }
 
 void Box_Data_Details::set_found_set_from_primary_key_value()
@@ -157,20 +156,21 @@ void Box_Data_Details::set_found_set_from_primary_key_value()
 
   if(!m_primary_key_value.is_null())
   {
+    //TODO: Use a SQL parameter instead of using sql().
     m_found_set.m_where_clause = "\"" + m_table_name + "\".\"" + m_field_primary_key->get_name() + 
       "\" = " + m_field_primary_key->sql(m_primary_key_value);
     //std::cout << "  DEBUG: Box_Data_Details::set_primary_key_value(): m_found_set.m_where_clause = " << m_found_set.m_where_clause << std::endl;
   }
 }
 
-bool Box_Data_Details::init_db_details(const FoundSet& found_set, const Gnome::Gda::Value& primary_key_value)
+bool Box_Data_Details::init_db_details(const FoundSet& found_set, const Glib::ustring& layout_platform, const Gnome::Gda::Value& primary_key_value)
 {
   //std::cout << "Box_Data_Details::init_db_details(): primary_key_value=" << primary_key_value.to_string() << std::endl;
 
   m_primary_key_value = primary_key_value;
   m_field_primary_key = get_field_primary_key_for_table(found_set.m_table_name);
    
-  const bool result = Box_Data::init_db_details(found_set); //Calls create_layout(), then fill_from_database()
+  const bool result = Box_Data::init_db_details(found_set, layout_platform); //Calls create_layout(), then fill_from_database()
 
   //This is not used much, but we create it anyway:
   m_found_set = found_set; //Not used much.
@@ -206,7 +206,7 @@ void Box_Data_Details::create_layout()
     m_FlowTable.set_table(m_table_name); //This allows portals to get full Relationship information
 
     //This map of layout groups will also contain the field information from the database:
-    Document_Glom::type_list_layout_groups layout_groups = get_data_layout_groups(m_layout_name);
+    Document_Glom::type_list_layout_groups layout_groups = get_data_layout_groups(m_layout_name, m_layout_platform);
 
     for(Document_Glom::type_list_layout_groups::const_iterator iter = layout_groups.begin(); iter != layout_groups.end(); ++iter)
     {
@@ -333,7 +333,7 @@ bool Box_Data_Details::fill_from_database()
         Glib::RefPtr<Gnome::Gda::DataModel> result;
 
         if(!primary_key_is_empty)
-          result = query_execute(query, get_app_window());
+          result = query_execute_select(query);
 
         if((result && result->get_n_rows()) || primary_key_is_empty) //either a working result or no result needed.
         {
@@ -405,7 +405,7 @@ void Box_Data_Details::on_button_new()
     //Warn the user that they won't see anything if there are no fields on the layout,
     //doing an extra check:
     Document_Glom* document = get_document();
-    if( document && !(document->get_data_layout_groups_have_any_fields(m_layout_name, m_table_name)) )
+    if( document && !(document->get_data_layout_groups_have_any_fields(m_layout_name, m_table_name, m_layout_platform)) )
     {
       Gtk::Window* parent_window = get_app_window();
       if(parent_window)
@@ -607,7 +607,7 @@ void Box_Data_Details::on_flowtable_layout_changed()
   //Store it in the document:
   Document_Glom* document = get_document();
   if(document)
-    document->set_data_layout_groups(m_layout_name, m_table_name, layout_groups);
+    document->set_data_layout_groups(m_layout_name, m_table_name, m_layout_platform, layout_groups);
   //Build the view again from the new layout:
 #endif
   create_layout();
@@ -615,7 +615,7 @@ void Box_Data_Details::on_flowtable_layout_changed()
   //Store it in the document:
   Document_Glom* document = get_document();
   if(document)
-    document->set_modified (true);
+    document->set_modified();
     
     
   //And fill it with data:
@@ -641,10 +641,24 @@ void Box_Data_Details::on_flowtable_field_open_details_requested(const sharedptr
   if(Conversions::value_is_empty(field_value))
     return; //Ignore empty ID fields.
 
-  sharedptr<Relationship> relationship = get_document()->get_field_used_in_relationship_to_one(m_table_name, layout_field->get_name());
+  //If it's a simple field that is part of a relationship, 
+  //identifying a related record.
+  sharedptr<const Relationship> relationship = get_document()->get_field_used_in_relationship_to_one(m_table_name, layout_field);
   if(relationship)
   {
     signal_requested_related_details().emit(relationship->get_to_table(), field_value);
+    return;
+  }
+
+  //If it is a related field that is a primary key,
+  //meaning it identifies a record in another table:
+  sharedptr<const Field> field_info = layout_field->get_full_field_details();
+  const bool field_is_related_primary_key = 
+    layout_field->get_has_relationship_name() && 
+    field_info && field_info->get_primary_key();
+  if(field_is_related_primary_key)
+  {
+    signal_requested_related_details().emit(layout_field->get_table_used(m_table_name), field_value);   
   }
 }
 
@@ -760,6 +774,10 @@ void Box_Data_Details::on_flowtable_field_edited(const sharedptr<const LayoutIte
       bTest = set_field_value_in_database(field_in_record, field_value, false /* don't use current calculations */, get_app_window());
     }
 #ifdef GLIBMM_EXCEPTIONS_ENABLED
+    catch(const Glib::Exception& ex)
+    {
+      handle_error(ex);
+    }
     catch(const std::exception& ex)
     {
       handle_error(ex);
@@ -773,7 +791,9 @@ void Box_Data_Details::on_flowtable_field_edited(const sharedptr<const LayoutIte
       if(!bTest)
       {
         //Update failed.
-        fill_from_database(); //Replace with correct values.
+        //Replace with correct values.
+        const Gnome::Gda::Value value_old = get_field_value_in_database(field_in_record, window);
+        set_entered_field_data(layout_field, value_old);
       }
       else
       {
@@ -871,8 +891,8 @@ void Box_Data_Details::on_userlevel_changed(AppState::userlevels user_level)
 #ifndef GLOM_ENABLE_CLIENT_ONLY
   m_design_mode = ( user_level == AppState::USERLEVEL_DEVELOPER );    
   m_FlowTable.set_design_mode(m_design_mode);
-	// Recreate layout to correctly set the size of empty flowtables
-	create_layout();
+  // Recreate the layout to correctly set the size of empty flowtables:
+  create_layout();
 #endif
 }
 
@@ -966,7 +986,7 @@ void Box_Data_Details::print_layout()
     //The groups:
     xmlpp::Element* nodeParent = nodeRoot;
 
-    Document_Glom::type_list_layout_groups layout_groups = get_data_layout_groups(m_layout_name);
+    Document_Glom::type_list_layout_groups layout_groups = get_data_layout_groups(m_layout_name, m_layout_platform);
     for(Document_Glom::type_list_layout_groups::const_iterator iter = layout_groups.begin(); iter != layout_groups.end(); ++iter)
     {
       sharedptr<const LayoutGroup> layout_group = *iter;
@@ -993,7 +1013,8 @@ Dialog_Layout* Box_Data_Details::create_layout_dialog() const
 
 void Box_Data_Details::prepare_layout_dialog(Dialog_Layout* dialog)
 {
-  dialog->set_document(m_layout_name, get_document(), m_table_name, m_FieldsShown); //TODO: Use m_TableFields?
+  if(dialog)
+    dialog->set_document(m_layout_name, m_layout_platform, get_document(), m_table_name, m_FieldsShown); //TODO: Use m_TableFields?
 }
 
 void Box_Data_Details::show_layout_toolbar(bool show)
