@@ -22,6 +22,7 @@
 #include "dialog_choose_relationship.h"
 #include "../layout_item_dialogs/dialog_buttonscript.h"
 #include "../layout_item_dialogs/dialog_notebook.h"
+#include <glom/libglom/glade_utils.h>
 #include "../frame_glom.h" //For show_ok_dialog()
 //#include <libgnome/gnome-i18n.h>
 #include <bakery/App/App_Gtk.h> //For util_bold_message().
@@ -35,15 +36,18 @@ Dialog_Layout_Details::Dialog_Layout_Details(BaseObjectType* cobject, const Glib
 : Dialog_Layout(cobject, refGlade),
   m_treeview_fields(0),
   m_treeview_column_title(0),
+  m_treeview_column_group_columns(0),
+  m_treeview_column_column_width(0),
   m_box_table_widgets(0),
   m_box_related_table_widgets(0),
   m_box_related_navigation(0),
-  m_button_field_up(0),
-  m_button_field_down(0),
-  m_button_field_add(0),
-  m_button_field_add_group(0),
+  m_button_up(0),
+  m_button_down(0),
+  m_button_add_field(0),
+  m_button_add_group(0),
   m_button_add_notebook(0),
   m_button_add_related(0),
+  m_button_add_related_calendar(0),
   m_button_add_button(0),
   m_button_add_text(0),
   m_button_add_image(0),
@@ -61,6 +65,10 @@ Dialog_Layout_Details::Dialog_Layout_Details(BaseObjectType* cobject, const Glib
   refGlade->get_widget("frame_related_table_navigation", m_box_related_navigation); 
   m_box_related_navigation->hide();
 
+  Gtk::Frame* box_calendar = 0;
+  refGlade->get_widget("frame_calendar", box_calendar); 
+  box_calendar->hide();
+
   refGlade->get_widget("label_table_name", m_label_table_name);
 
   refGlade->get_widget("treeview_fields", m_treeview_fields);
@@ -102,15 +110,33 @@ Dialog_Layout_Details::Dialog_Layout_Details(BaseObjectType* cobject, const Glib
 
 
     //Columns-count column:
-    Gtk::TreeView::Column* column_count = Gtk::manage( new Gtk::TreeView::Column(_("Columns Count")) );
-    m_treeview_fields->append_column(*column_count);
+    m_treeview_column_group_columns = Gtk::manage( new Gtk::TreeView::Column(_("Group Columns")) );
+    m_treeview_fields->append_column(*m_treeview_column_group_columns);
 
     Gtk::CellRendererText* renderer_count = Gtk::manage(new Gtk::CellRendererText);
-    column_count->pack_start(*renderer_count);
-    column_count->set_cell_data_func(*renderer_count, sigc::mem_fun(*this, &Dialog_Layout_Details::on_cell_data_columns_count));
+    m_treeview_column_group_columns->pack_start(*renderer_count);
+    m_treeview_column_group_columns->set_cell_data_func(*renderer_count, sigc::mem_fun(*this, &Dialog_Layout_Details::on_cell_data_group_columns));
 
     //Connect to its signal:
-    renderer_count->signal_edited().connect( sigc::mem_fun(*this, &Dialog_Layout_Details::on_treeview_cell_edited_columns_count) );
+    renderer_count->signal_edited().connect( sigc::mem_fun(*this, &Dialog_Layout_Details::on_treeview_cell_edited_group_columns) );
+
+
+    //Column-Width column: (only for list views)
+    //Note to translators: This is a name (the width of a UI element in the display), not an action.
+    m_treeview_column_column_width = Gtk::manage( new Gtk::TreeView::Column(_("Display Width")) );
+    m_treeview_fields->append_column(*m_treeview_column_column_width);
+
+    Gtk::CellRendererText* renderer_column_width = Gtk::manage(new Gtk::CellRendererText);
+    m_treeview_column_column_width->pack_start(*renderer_column_width);
+    m_treeview_column_column_width->set_cell_data_func(*renderer_column_width, sigc::mem_fun(*this, &Dialog_Layout_Details::on_cell_data_column_width));
+
+    //Connect to its signal:
+    renderer_column_width->signal_edited().connect( sigc::mem_fun(*this, &Dialog_Layout_Details::on_treeview_cell_edited_column_width) );
+
+    //Hide this column because we don't need it for the details layout.
+    //It is made visible by the (derived) list layout class.
+    m_treeview_column_column_width->set_visible(false);
+
 
     //Respond to changes of selection:
     Glib::RefPtr<Gtk::TreeView::Selection> refSelection = m_treeview_fields->get_selection();
@@ -122,11 +148,11 @@ Dialog_Layout_Details::Dialog_Layout_Details(BaseObjectType* cobject, const Glib
     m_model_items->signal_row_changed().connect( sigc::mem_fun(*this, &Dialog_Layout_Details::on_treemodel_row_changed) );
   }
 
-  refGlade->get_widget("button_field_up", m_button_field_up);
-  m_button_field_up->signal_clicked().connect( sigc::mem_fun(*this, &Dialog_Layout_Details::on_button_field_up) );
+  refGlade->get_widget("button_up", m_button_up);
+  m_button_up->signal_clicked().connect( sigc::mem_fun(*this, &Dialog_Layout_Details::on_button_up) );
 
-  refGlade->get_widget("button_field_down", m_button_field_down);
-  m_button_field_down->signal_clicked().connect( sigc::mem_fun(*this, &Dialog_Layout_Details::on_button_field_down) );
+  refGlade->get_widget("button_down", m_button_down);
+  m_button_down->signal_clicked().connect( sigc::mem_fun(*this, &Dialog_Layout_Details::on_button_down) );
 
   refGlade->get_widget("button_field_delete", m_button_field_delete);
   m_button_field_delete->signal_clicked().connect( sigc::mem_fun(*this, &Dialog_Layout_Details::on_button_field_delete) );
@@ -134,11 +160,11 @@ Dialog_Layout_Details::Dialog_Layout_Details(BaseObjectType* cobject, const Glib
   refGlade->get_widget("button_formatting", m_button_field_formatting);
   m_button_field_formatting->signal_clicked().connect( sigc::mem_fun(*this, &Dialog_Layout_Details::on_button_field_formatting) );
 
-  refGlade->get_widget("button_field_add", m_button_field_add);
-  m_button_field_add->signal_clicked().connect( sigc::mem_fun(*this, &Dialog_Layout_Details::on_button_field_add) );
+  refGlade->get_widget("button_add_field", m_button_add_field);
+  m_button_add_field->signal_clicked().connect( sigc::mem_fun(*this, &Dialog_Layout_Details::on_button_add_field) );
 
-  refGlade->get_widget("button_field_add_group", m_button_field_add_group);
-  m_button_field_add_group->signal_clicked().connect( sigc::mem_fun(*this, &Dialog_Layout_Details::on_button_field_add_group) );
+  refGlade->get_widget("button_add_group", m_button_add_group);
+  m_button_add_group->signal_clicked().connect( sigc::mem_fun(*this, &Dialog_Layout_Details::on_button_add_group) );
 
   refGlade->get_widget("button_add_notebook", m_button_add_notebook);
   m_button_add_notebook->signal_clicked().connect( sigc::mem_fun(*this, &Dialog_Layout_Details::on_button_add_notebook) );
@@ -146,6 +172,9 @@ Dialog_Layout_Details::Dialog_Layout_Details(BaseObjectType* cobject, const Glib
   refGlade->get_widget("button_add_related", m_button_add_related);
   m_button_add_related->signal_clicked().connect( sigc::mem_fun(*this, &Dialog_Layout_Details::on_button_add_related) );
 
+  refGlade->get_widget("button_add_related_calendar", m_button_add_related_calendar);
+  m_button_add_related_calendar->signal_clicked().connect( sigc::mem_fun(*this, &Dialog_Layout_Details::on_button_add_related_calendar) );
+
   refGlade->get_widget("button_add_button", m_button_add_button);
   m_button_add_button->signal_clicked().connect( sigc::mem_fun(*this, &Dialog_Layout_Details::on_button_add_button) );
 
@@ -254,10 +283,10 @@ void Dialog_Layout_Details::add_group(const Gtk::TreeModel::iterator& parent, co
     rowGroup[m_model_items->m_columns.m_col_layout_item] = group_inserted;
 
     //Add the child items: (TODO_Performance: The child items are ignored/wasted because we clone them again.)
-    LayoutGroup::type_map_const_items items = group->get_items();
-    for(LayoutGroup::type_map_const_items::const_iterator iter = items.begin(); iter != items.end(); ++iter)
+    LayoutGroup::type_list_const_items items = group->get_items();
+    for(LayoutGroup::type_list_const_items::const_iterator iter = items.begin(); iter != items.end(); ++iter)
     {
-      sharedptr<const LayoutItem> item = iter->second;
+      sharedptr<const LayoutItem> item = *iter;
 
       sharedptr<const LayoutItem_Portal> portal = sharedptr<const LayoutItem_Portal>::cast_dynamic(item);
       if(portal) //If it is a portal
@@ -286,12 +315,11 @@ void Dialog_Layout_Details::add_group(const Gtk::TreeModel::iterator& parent, co
   }
 }
 
-void Dialog_Layout_Details::set_document(const Glib::ustring& layout, Document_Glom* document, const Glib::ustring& table_name, const type_vecLayoutFields& table_fields)
+void Dialog_Layout_Details::set_document(const Glib::ustring& layout_name, const Glib::ustring& layout_platform, Document_Glom* document, const Glib::ustring& table_name, const type_vecLayoutFields& table_fields)
 {
   m_modified = false;
 
-  Dialog_Layout::set_document(layout, document, table_name, table_fields);
-
+  Dialog_Layout::set_document(layout_name, layout_platform, document, table_name, table_fields);
 
   //Update the tree models from the document
   if(document)
@@ -300,43 +328,28 @@ void Dialog_Layout_Details::set_document(const Glib::ustring& layout, Document_G
     m_label_table_name->set_text(table_name);
     m_entry_table_title->set_text( document->get_table_title(table_name) );
 
-    Document_Glom::type_mapLayoutGroupSequence mapGroups = document->get_data_layout_groups_plus_new_fields(layout, m_table_name);
-    document->fill_layout_field_details(m_table_name, mapGroups); //Update with full field information.
+    Document_Glom::type_list_layout_groups list_groups = document->get_data_layout_groups_plus_new_fields(m_layout_name, m_table_name, m_layout_platform);
+    document->fill_layout_field_details(m_table_name, list_groups); //Update with full field information.
 
-    //If no information is stored in the document, then start with something:
+    //If no information is stored in the document, add a default group
 
-    if(mapGroups.empty())
+    if(list_groups.empty())
     {
       sharedptr<LayoutGroup> group = sharedptr<LayoutGroup>::create();
       group->set_name("main");
-      group->m_columns_count = 2;
+      group->m_columns_count = 1;
 
-      guint field_sequence = 1; //0 means no sequence
-      for(type_vecLayoutFields::const_iterator iter = table_fields.begin(); iter != table_fields.end(); ++iter)
-      {
-        sharedptr<LayoutItem_Field> item = *iter;
-        item->m_sequence = field_sequence;
-
-        group->add_item(item, field_sequence);
-
-        ++field_sequence;
-      }
-
-      mapGroups[1] = group;
-    }
+      list_groups.push_back(group);
+    }      
 
     //Show the field layout
     //typedef std::list< Glib::ustring > type_listStrings;
 
     m_model_items->clear();
 
-    //guint field_sequence = 1; //0 means no sequence
-    //guint group_sequence = 1; //0 means no sequence
-    for(Document_Glom::type_mapLayoutGroupSequence::const_iterator iter = mapGroups.begin(); iter != mapGroups.end(); ++iter)
+    for(Document_Glom::type_list_layout_groups::const_iterator iter = list_groups.begin(); iter != list_groups.end(); ++iter)
     {
-      sharedptr<const LayoutGroup> group = iter->second;
-      //std::cout << "debug: Dialog_Layout_Details::set_document(): adding group name=" << group->get_name() << std::endl;
-        
+      sharedptr<const LayoutGroup> group = *iter;
       sharedptr<const LayoutGroup> portal = sharedptr<const LayoutItem_Portal>::cast_dynamic(group);
       if(group && !portal)
         add_group(Gtk::TreeModel::iterator() /* null == top-level */, group);
@@ -376,7 +389,7 @@ void Dialog_Layout_Details::enable_buttons()
           enable_up = false;  //It can't go any higher.
       }
 
-      m_button_field_up->set_sensitive(enable_up);
+      m_button_up->set_sensitive(enable_up);
 
 
       //Disable Down if It can't go any lower.
@@ -397,7 +410,7 @@ void Dialog_Layout_Details::enable_buttons()
           enable_down = false;
       }
 
-      m_button_field_down->set_sensitive(enable_down);
+      m_button_down->set_sensitive(enable_down);
 
       m_button_field_delete->set_sensitive(true);
 
@@ -410,8 +423,8 @@ void Dialog_Layout_Details::enable_buttons()
     else
     {
       //Disable all buttons that act on a selection:
-      m_button_field_down->set_sensitive(false);
-      m_button_field_up->set_sensitive(false);
+      m_button_down->set_sensitive(false);
+      m_button_up->set_sensitive(false);
       m_button_field_delete->set_sensitive(false);
       m_button_field_formatting->set_sensitive(false);
     }
@@ -436,7 +449,7 @@ void Dialog_Layout_Details::on_button_field_delete()
   }
 }
 
-void Dialog_Layout_Details::on_button_field_up()
+void Dialog_Layout_Details::on_button_up()
 {
   Glib::RefPtr<Gtk::TreeView::Selection> refSelection = m_treeview_fields->get_selection();
   if(refSelection)
@@ -467,7 +480,7 @@ void Dialog_Layout_Details::on_button_field_up()
   enable_buttons();
 }
 
-void Dialog_Layout_Details::on_button_field_down()
+void Dialog_Layout_Details::on_button_down()
 {
   Glib::RefPtr<Gtk::TreeView::Selection> refSelection = m_treeview_fields->get_selection();
   if(refSelection)
@@ -499,7 +512,7 @@ void Dialog_Layout_Details::on_button_field_down()
   enable_buttons();
 }
 
-void Dialog_Layout_Details::on_button_field_add()
+void Dialog_Layout_Details::on_button_add_field()
 {
   sharedptr<LayoutItem_Field> layout_item = offer_field_list(m_table_name, this);
   if(layout_item)
@@ -532,7 +545,7 @@ sharedptr<LayoutItem_Button> Dialog_Layout_Details::offer_button_script_edit(con
 
   try
   {
-    Glib::RefPtr<Gnome::Glade::Xml> refXml = Gnome::Glade::Xml::create(GLOM_GLADEDIR "glom.glade", "window_button_script");
+    Glib::RefPtr<Gnome::Glade::Xml> refXml = Gnome::Glade::Xml::create(Utils::get_glade_file_path("glom_developer.glade"), "window_button_script");
 
     Dialog_ButtonScript* dialog = 0;
     refXml->get_widget_derived("window_button_script", dialog);
@@ -567,7 +580,7 @@ sharedptr<LayoutItem_Text> Dialog_Layout_Details::offer_textobject_edit(const sh
 
   try
   {
-    Glib::RefPtr<Gnome::Glade::Xml> refXml = Gnome::Glade::Xml::create(GLOM_GLADEDIR "glom.glade", "window_textobject");
+    Glib::RefPtr<Gnome::Glade::Xml> refXml = Gnome::Glade::Xml::create(Utils::get_glade_file_path("glom_developer.glade"), "window_textobject");
 
     Dialog_TextObject* dialog = 0;
     refXml->get_widget_derived("window_textobject", dialog);
@@ -607,7 +620,7 @@ sharedptr<Relationship> Dialog_Layout_Details::offer_relationship_list(const sha
 
   try
   {
-    Glib::RefPtr<Gnome::Glade::Xml> refXml = Gnome::Glade::Xml::create(GLOM_GLADEDIR "glom.glade", "dialog_choose_relationship");
+    Glib::RefPtr<Gnome::Glade::Xml> refXml = Gnome::Glade::Xml::create(Utils::get_glade_file_path("glom_developer.glade"), "dialog_choose_relationship");
 
     Dialog_ChooseRelationship* dialog = 0;
     refXml->get_widget_derived("dialog_choose_relationship", dialog);
@@ -643,9 +656,10 @@ Gtk::TreeModel::iterator Dialog_Layout_Details::append_appropriate_row()
   Gtk::TreeModel::iterator parent = get_selected_group_parent();
 
   //Add the field details to the layout treeview:
-  Gtk::TreeModel::iterator iter;
   if(parent)
+  {
     result = m_model_items->append(parent->children());
+  }
   else
   {
     //Find the first group, and make the new row a child of that:
@@ -661,6 +675,12 @@ Gtk::TreeModel::iterator Dialog_Layout_Details::append_appropriate_row()
       if(layout_group && !layout_portal)
         result = m_model_items->append(iter_first->children());
     }
+
+    if(!result)
+    {
+      //For instance, for a Dialog_Layout_List_Related derived class, with a portal as the top-level group:
+      result = m_model_items->append();
+    }
   }
 
   return result;
@@ -771,16 +791,18 @@ void Dialog_Layout_Details::on_button_add_related()
 {
   Gtk::TreeModel::iterator parent = get_selected_group_parent();
 
+  /* We don't need to ask this because the portal layout dialog can now handle an empty portal:
   sharedptr<Relationship> relationship = offer_relationship_list();
   if(relationship)
   {
+  */
     Gtk::TreeModel::iterator iter = append_appropriate_row();
     if(iter)
     {
       Gtk::TreeModel::Row row = *iter;
 
       sharedptr<LayoutItem_Portal> portal = sharedptr<LayoutItem_Portal>::create();
-      portal->set_relationship(relationship);
+      //portal->set_relationship(relationship);
       row[m_model_items->m_columns.m_col_layout_item] = portal;
 
       //Scroll to, and select, the new row:
@@ -792,7 +814,41 @@ void Dialog_Layout_Details::on_button_add_related()
 
       m_modified = true;
     }
+  /*
   }
+  */
+
+  enable_buttons();
+}
+
+void Dialog_Layout_Details::on_button_add_related_calendar()
+{
+  Gtk::TreeModel::iterator parent = get_selected_group_parent();
+
+  /* We don't need to ask this because the portal layout dialog can now handle an empty portal:
+  sharedptr<Relationship> relationship = offer_relationship_list();
+  if(relationship)
+  {
+  */
+    Gtk::TreeModel::iterator iter = append_appropriate_row();
+    if(iter)
+    {
+      Gtk::TreeModel::Row row = *iter;
+
+      sharedptr<LayoutItem_Portal> portal = sharedptr<LayoutItem_CalendarPortal>::create();
+      //portal->set_relationship(relationship);
+      row[m_model_items->m_columns.m_col_layout_item] = portal;
+
+      //Scroll to, and select, the new row:
+      Glib::RefPtr<Gtk::TreeSelection> refTreeSelection = m_treeview_fields->get_selection();
+      if(refTreeSelection)
+        refTreeSelection->select(iter);
+
+      m_treeview_fields->scroll_to_row( Gtk::TreeModel::Path(iter) );
+
+      m_modified = true;
+    }
+  //}
 
   enable_buttons();
 }
@@ -831,7 +887,7 @@ Gtk::TreeModel::iterator Dialog_Layout_Details::get_selected_group_parent() cons
   return parent;
 }
 
-void Dialog_Layout_Details::on_button_field_add_group()
+void Dialog_Layout_Details::on_button_add_group()
 {
   Gtk::TreeModel::iterator parent = get_selected_group_parent();
 
@@ -888,7 +944,7 @@ void Dialog_Layout_Details::on_button_field_formatting()
         {
           *field = *chosenitem; //TODO_Performance.
           m_modified = true;
-          //m_model_parts->row_changed(Gtk::TreePath(iter), iter); //TODO: Add row_changed(iter) to gtkmm?
+          //m_model_parts->row_changed(Gtk::TreeModel::Path(iter), iter); //TODO: Add row_changed(iter) to gtkmm?
         }
       }
     }
@@ -945,8 +1001,8 @@ void Dialog_Layout_Details::on_button_edit()
           sharedptr<LayoutGroup> layout_group = sharedptr<LayoutGroup>::cast_dynamic(layout_item);
           if(layout_group)
           {
-              Gtk::TreeModel::Path path = m_model_items->get_path(iter);
-              m_treeview_fields->set_cursor(path, *m_treeview_column_title, true /* start_editing */);
+            Gtk::TreeModel::Path path = m_model_items->get_path(iter);
+            m_treeview_fields->set_cursor(path, *m_treeview_column_title, true /* start_editing */);
           }
           else
           {
@@ -1037,11 +1093,9 @@ void Dialog_Layout_Details::save_to_document()
     m_model_items->fill_sequences();
 
     //Get the groups and their fields:
-    Document_Glom::type_mapLayoutGroupSequence mapGroups;
-    guint group_sequence = 1; //0 means no sequence
+    Document_Glom::type_list_layout_groups list_groups;
 
     //Add the layout items:
-    //guint field_sequence = 1; //0 means no sequence
     for(Gtk::TreeModel::iterator iterFields = m_model_items->children().begin(); iterFields != m_model_items->children().end(); ++iterFields)
     {
       Gtk::TreeModel::Row row = *iterFields;
@@ -1054,17 +1108,13 @@ void Dialog_Layout_Details::save_to_document()
         sharedptr<LayoutGroup> group = sharedptr<LayoutGroup>::create();
         fill_group(iterFields, group);
 
-        group->m_sequence = group_sequence;
-        mapGroups[group_sequence] = group;
-        //std::cout << "debug: Dialog_Layout_Details::save_to_document(): adding group sequence=" << group_sequence << ", group->m_sequence=" << group->m_sequence << ". group name=" << group->get_name() << std::endl;
-        
-        ++group_sequence;
+        list_groups.push_back(group);
       }
     }
 
     if(document)
     {
-      document->set_data_layout_groups(m_layout_name, m_table_name, mapGroups);
+      document->set_data_layout_groups(m_layout_name, m_table_name, m_layout_platform, list_groups);
       m_modified = false;
     }
   }
@@ -1097,7 +1147,11 @@ void Dialog_Layout_Details::on_cell_data_name(Gtk::CellRenderer* renderer, const
       sharedptr<LayoutItem_Portal> layout_portal = sharedptr<LayoutItem_Portal>::cast_dynamic(layout_item);
       if(layout_portal)
       {
-        markup = _("Related: ") + layout_portal->get_relationship_name();
+        sharedptr<LayoutItem_CalendarPortal> layout_calendar = sharedptr<LayoutItem_CalendarPortal>::cast_dynamic(layout_portal);
+        if(layout_calendar)
+          markup = _("Related Calendar: ") + layout_portal->get_relationship_name();
+        else
+          markup = _("Related List: ") + layout_portal->get_relationship_name();
       }
       else
       {
@@ -1143,6 +1197,8 @@ void Dialog_Layout_Details::on_cell_data_name(Gtk::CellRenderer* renderer, const
                 }
                 else if(layout_item)
                   markup = layout_item->get_name();
+                else
+                  markup = Glib::ustring();
               }
             }
           }
@@ -1172,8 +1228,10 @@ void Dialog_Layout_Details::on_cell_data_title(Gtk::CellRenderer* renderer, cons
       sharedptr<LayoutItem_Notebook> layout_notebook = sharedptr<LayoutItem_Notebook>::cast_dynamic(layout_item);
       if(layout_notebook)
         renderer_text->property_text() = _("(Notebook)");
-      else
+      else if(layout_item)
         renderer_text->property_text() = layout_item->get_title();
+      else
+        renderer_text->property_text() = Glib::ustring();
 
       sharedptr<LayoutGroup> layout_group = sharedptr<LayoutGroup>::cast_dynamic(layout_item);
       sharedptr<LayoutItem_Portal> layout_portal = sharedptr<LayoutItem_Portal>::cast_dynamic(layout_item);
@@ -1185,7 +1243,39 @@ void Dialog_Layout_Details::on_cell_data_title(Gtk::CellRenderer* renderer, cons
   }
 }
 
-void Dialog_Layout_Details::on_cell_data_columns_count(Gtk::CellRenderer* renderer, const Gtk::TreeModel::iterator& iter)
+void Dialog_Layout_Details::on_cell_data_column_width(Gtk::CellRenderer* renderer, const Gtk::TreeModel::iterator& iter)
+{
+  //Set the view's cell properties depending on the model's data:
+  Gtk::CellRendererText* renderer_text = dynamic_cast<Gtk::CellRendererText*>(renderer);
+  if(renderer_text)
+  {
+    if(iter)
+    {
+      Gtk::TreeModel::Row row = *iter;
+      sharedptr<LayoutItem> layout_item = row[m_model_items->m_columns.m_col_layout_item];
+
+      guint column_width = 0;
+      if(layout_item)
+      {
+        sharedptr<LayoutItem_Button> layout_button = sharedptr<LayoutItem_Button>::cast_dynamic(layout_item);
+        sharedptr<LayoutItem_Text> layout_text = sharedptr<LayoutItem_Text>::cast_dynamic(layout_item);
+        sharedptr<LayoutItem_Field> layout_field = sharedptr<LayoutItem_Field>::cast_dynamic(layout_item);
+        const bool editable = (layout_field || layout_button || layout_text); //Only these have column widths that can be edited.
+        renderer_text->property_editable() = editable;
+      
+        layout_item->get_display_width(column_width);
+      }
+
+      Glib::ustring text; 
+      if(column_width) //Show nothing if no width has been specified, meaning that it's automatic.
+        text = Utils::string_from_decimal(column_width);
+
+      renderer_text->property_text() = text;
+    }
+  }
+}
+
+void Dialog_Layout_Details::on_cell_data_group_columns(Gtk::CellRenderer* renderer, const Gtk::TreeModel::iterator& iter)
 {
   //Set the view's cell properties depending on the model's data:
   Gtk::CellRendererText* renderer_text = dynamic_cast<Gtk::CellRendererText*>(renderer);
@@ -1205,11 +1295,7 @@ void Dialog_Layout_Details::on_cell_data_columns_count(Gtk::CellRenderer* render
       Glib::ustring text;
       if(is_group)
       {
-        std::stringstream the_stream;
-        //the_stream.imbue(std::locale::classic());
-        const guint number = layout_group->m_columns_count;
-        the_stream << number;
-        text = the_stream.str();
+        text = Utils::string_from_decimal(layout_group->m_columns_count);
       }
       else
       {
@@ -1226,7 +1312,7 @@ void Dialog_Layout_Details::on_treeview_cell_edited_title(const Glib::ustring& p
 {
   if(!path_string.empty())
   {
-    Gtk::TreePath path(path_string);
+    Gtk::TreeModel::Path path(path_string);
 
     //Get the row from the path:
     Gtk::TreeModel::iterator iter = m_model_items->get_iter(path);
@@ -1246,11 +1332,12 @@ void Dialog_Layout_Details::on_treeview_cell_edited_title(const Glib::ustring& p
   }
 }
 
+
 void Dialog_Layout_Details::on_treeview_cell_edited_name(const Glib::ustring& path_string, const Glib::ustring& new_text)
 {
   if(!path_string.empty())
   {
-    Gtk::TreePath path(path_string);
+    Gtk::TreeModel::Path path(path_string);
 
     //Get the row from the path:
     Gtk::TreeModel::iterator iter = m_model_items->get_iter(path);
@@ -1270,13 +1357,41 @@ void Dialog_Layout_Details::on_treeview_cell_edited_name(const Glib::ustring& pa
   }
 }
 
-void Dialog_Layout_Details::on_treeview_cell_edited_columns_count(const Glib::ustring& path_string, const Glib::ustring& new_text)
+void Dialog_Layout_Details::on_treeview_cell_edited_column_width(const Glib::ustring& path_string, const Glib::ustring& new_text)
+{
+  if(!path_string.empty())
+  {
+    Gtk::TreeModel::Path path(path_string);
+
+    //Get the row from the path:
+    Gtk::TreeModel::iterator iter = m_model_items->get_iter(path);
+    if(iter)
+    {
+      Gtk::TreeModel::Row row = *iter;
+      sharedptr<LayoutItem> layout_item = row[m_model_items->m_columns.m_col_layout_item];
+      if(layout_item)
+      {
+        //Convert the text to a number, using the same logic used by GtkCellRendererText when it stores numbers.
+        char* pchEnd = 0;
+        const guint new_value = static_cast<guint>( strtod(new_text.c_str(), &pchEnd) );
+
+        //Store the user's new value in the model:
+        Gtk::TreeRow row = *iter;
+        layout_item->set_display_width(new_value);
+
+        m_modified = true;
+      }
+    }
+  }
+}
+
+void Dialog_Layout_Details::on_treeview_cell_edited_group_columns(const Glib::ustring& path_string, const Glib::ustring& new_text)
 {
   //This is used on numerical model columns:
   if(path_string.empty())
     return;
 
-  Gtk::TreePath path(path_string);
+  Gtk::TreeModel::Path path(path_string);
 
   //Get the row from the path:
   Gtk::TreeModel::iterator iter = m_model_items->get_iter(path);
