@@ -275,9 +275,12 @@ void DbTreeModelRow::fill_values_if_necessary(DbTreeModel& model, int row)
           if(holder)
             m_db_values[i] = holder->get_value(); //TODO_gda: Why not just use get_value_at()?
           else
-            std::cerr << "DbTreeModelRow::fill_values_if_necessary(): NULL Gnome::Gda::Holder for field=" << i << std::endl;
+          {
+            // This is quite possible, for example for unset dates. jhs 
+            //std::cerr << "DbTreeModelRow::fill_values_if_necessary(): NULL Gnome::Gda::Holder for field=" << i << std::endl;
+          }
 
-          //std::cout << "  debug: col=" << i << ", GType=" << m_db_values[i].get_value_type() << std::endl;
+          //std::cout << "  debug: col=" << i << ", GType=" << m_db_values[i].get_value_type() << ", string=" << m_db_values[i].to_string() << std::endl;
         }
 
         Glib::RefPtr<const Gnome::Gda::Holder> holder = iter->get_holder_for_field(model.m_column_index_key);
@@ -367,7 +370,7 @@ DbTreeModelRow::DbValue DbTreeModelRow::get_value(DbTreeModel& model, int column
 //Intialize static variable:
 bool DbTreeModel::m_iface_initialized = false;
 
-DbTreeModel::DbTreeModel(const Gtk::TreeModelColumnRecord& columns, const FoundSet& found_set, const type_vec_fields& column_fields, int column_index_key, bool get_records)
+DbTreeModel::DbTreeModel(const Gtk::TreeModelColumnRecord& columns, const FoundSet& found_set, const type_vec_fields& column_fields, int column_index_key, bool get_records, bool find_mode)
 : Glib::ObjectBase( typeid(DbTreeModel) ), //register a custom GType.
   Glib::Object(), //The custom GType is actually registered here.
   m_columns_count(0),
@@ -379,6 +382,7 @@ DbTreeModel::DbTreeModel(const Gtk::TreeModelColumnRecord& columns, const FoundS
   m_count_extra_rows(0),
   m_count_removed_rows(0),
   m_get_records(get_records),
+  m_find_mode(find_mode),
   m_stamp(1) //When the model's stamp != the iterator's stamp then that iterator is invalid and should be ignored. Also, 0=invalid
 {
   if(!m_iface_initialized)
@@ -420,9 +424,9 @@ DbTreeModel::~DbTreeModel()
 }
 
 //static:
-Glib::RefPtr<DbTreeModel> DbTreeModel::create(const Gtk::TreeModelColumnRecord& columns, const FoundSet& found_set, const type_vec_fields& column_fields, int column_index_key, bool get_records)
+Glib::RefPtr<DbTreeModel> DbTreeModel::create(const Gtk::TreeModelColumnRecord& columns, const FoundSet& found_set, const type_vec_fields& column_fields, int column_index_key, bool get_records, bool find_mode)
 {
-  return Glib::RefPtr<DbTreeModel>( new DbTreeModel(columns, found_set, column_fields, column_index_key, get_records) );
+  return Glib::RefPtr<DbTreeModel>( new DbTreeModel(columns, found_set, column_fields, column_index_key, get_records, find_mode) );
 }
 
 bool DbTreeModel::refresh_from_database(const FoundSet& found_set)
@@ -430,11 +434,40 @@ bool DbTreeModel::refresh_from_database(const FoundSet& found_set)
   //std::cout << "DbTreeModel::refresh_from_database()" << std::endl;
   m_found_set = found_set;
 
-  if(!m_get_records)
+  if(!m_get_records && !m_find_mode)
     return false;
 
   clear(); //Clear existing shown records.
 
+  if(m_find_mode)
+  {
+    m_get_records = false; //Otherwise it would not make sense.
+
+    //Use a dummy DataModel that has the same columns and types, 
+    //but which does not use a real database table,
+    //so we can use it to add find criteria.
+    Glib::RefPtr<Gnome::Gda::DataModelArray> model_array = Gnome::Gda::DataModelArray::create(m_column_fields.size());
+    m_gda_datamodel = model_array;
+
+    int col = 0;
+    for(type_vec_fields::const_iterator iter = m_column_fields.begin(); iter != m_column_fields.end(); ++iter)
+    {
+      sharedptr<const LayoutItem_Field> layout_item = *iter;
+      if(layout_item)
+      {
+        const Field::glom_field_type glom_type = layout_item->get_glom_type();
+        const GType gda_type = Field::get_gda_type_for_glom_type(glom_type);
+        model_array->set_column_g_type(col, gda_type);
+        ++col;
+      }
+    }
+
+    //Add at least an initial row:
+    m_gda_datamodel->append_row(); //TODO: Handle adding.
+    return true;
+  }
+
+
   //Connect to database:
   ConnectionPool* connection_pool = ConnectionPool::get_instance();
   if(connection_pool)
@@ -478,8 +511,20 @@ bool DbTreeModel::refresh_from_database(const FoundSet& found_set)
 #ifdef GLIBMM_EXCEPTIONS_ENABLED
     try
     {
-      //Specify the STATEMENT_MODEL_CURSOR, so that libgda only gets the rows that we actually use.   
-      m_gda_datamodel = m_connection->get_gda_connection()->statement_execute_select(stmt, Gnome::Gda::STATEMENT_MODEL_CURSOR);
+      //Specify the STATEMENT_MODEL_CURSOR, so that libgda only gets the rows that we actually use.
+      m_gda_datamodel = m_connection->get_gda_connection()->statement_execute_select(stmt, Gnome::Gda::STATEMENT_MODEL_CURSOR_FORWARD);
+
+      // Use a DataAccessWrapper to allow random access. This is necessary
+      // since we use move_to_row() on a created iterator in
+      // fill_values_if_necessary(), which does not work if the iterator
+      // does not support it (for example the one for Sqlite recordsets does
+      // not). The alternative would be to acquire a random-access model
+      // directly here for SQLite, but this would
+      // a) make this code dependent on the database backend used.
+      // b) fetch rows we perhaps don't need, if only the first few rows of
+      // a table are accessed.
+      // TODO_Performance: The unnecessary (for PostgreSQL) extra indirection might theoretically make this slower.
+      m_gda_datamodel = Gnome::Gda::DataAccessWrapper::create(m_gda_datamodel);
 
       if(app && app->get_show_sql_debug())
         std::cout << "  Debug: DbTreeModel::refresh_from_database(): The query execution has finished." << std::endl;
@@ -511,7 +556,7 @@ bool DbTreeModel::refresh_from_database(const FoundSet& found_set)
       m_gda_datamodel.clear(); //So that it is 0, so we can handle it below.
     }
 #endif //GLIBMM_EXCEPTIONS_ENABLED
-      
+
     if(!m_gda_datamodel)
     {
       m_data_model_rows_count = 0;
